@@ -46,6 +46,29 @@
 
 <dl>
 
+<dt><b>4.8.2</b> - <i>July 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.4.6 (SQLite version 3.39.1)</i><br>
+
+</dd>
+
+<dt><b>4.8.1</b> - <i>May 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.4.3 (SQLite version 3.38.5)</i><br>
+
+</dd>
+
+<dt><b>4.8.0</b> - <i>April 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.4.2 (SQLite version 3.38.3)</i><br>
+
+</dd>
+
+<dt><b>4.7.9</b> - <i>April 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.10 (SQLite version 3.38.2)</i><br>
+
+</dd>
 <dt><b>4.7.8</b> - <i>March 2022</i></dt>
 <dd>
 Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.9 (SQLite version 3.38.1)</i><br>
